Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(119)

Unified Diff: chrome/browser/sync_file_system/local/syncable_file_system_operation.h

Issue 23135019: Make SyncableFileSystemOperation not inherit from FileSystemOperationImpl (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/sync_file_system/local/syncable_file_system_operation.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/sync_file_system/local/syncable_file_system_operation.h
diff --git a/chrome/browser/sync_file_system/local/syncable_file_system_operation.h b/chrome/browser/sync_file_system/local/syncable_file_system_operation.h
index 211e5336552cbab36028def49bde50e1762c155a..86146b0256e947240dd26e962d129eb05fca0fb4 100644
--- a/chrome/browser/sync_file_system/local/syncable_file_system_operation.h
+++ b/chrome/browser/sync_file_system/local/syncable_file_system_operation.h
@@ -12,11 +12,13 @@
#include "base/memory/scoped_ptr.h"
#include "base/memory/weak_ptr.h"
#include "base/threading/non_thread_safe.h"
-#include "webkit/browser/fileapi/file_system_operation_impl.h"
+#include "webkit/browser/fileapi/file_system_operation.h"
+#include "webkit/browser/fileapi/file_system_url.h"
namespace fileapi {
class FileSystemContext;
class FileSystemOperationContext;
+class FileSystemOperationImpl;
class SandboxFileSystemBackend;
}
@@ -24,9 +26,9 @@ namespace sync_file_system {
class SyncableFileOperationRunner;
// A wrapper class of FileSystemOperationImpl for syncable file system.
class SyncableFileSystemOperation
- : public fileapi::FileSystemOperationImpl,
+ : public NON_EXPORTED_BASE(fileapi::FileSystemOperation),
public base::SupportsWeakPtr<SyncableFileSystemOperation>,
public base::NonThreadSafe {
public:
@@ -74,11 +76,22 @@ class SyncableFileSystemOperation
virtual void CreateSnapshotFile(
const fileapi::FileSystemURL& path,
const SnapshotFileCallback& callback) OVERRIDE;
-
- // FileSystemOperationImpl overrides.
virtual void CopyInForeignFile(const base::FilePath& src_local_disk_path,
const fileapi::FileSystemURL& dest_url,
const StatusCallback& callback) OVERRIDE;
+ virtual void RemoveFile(const fileapi::FileSystemURL& url,
+ const StatusCallback& callback) OVERRIDE;
+ virtual void RemoveDirectory(const fileapi::FileSystemURL& url,
+ const StatusCallback& callback) OVERRIDE;
+ virtual void CopyFileLocal(const fileapi::FileSystemURL& src_url,
+ const fileapi::FileSystemURL& dest_url,
+ const StatusCallback& callback) OVERRIDE;
+ virtual void MoveFileLocal(const fileapi::FileSystemURL& src_url,
+ const fileapi::FileSystemURL& dest_url,
+ const StatusCallback& callback) OVERRIDE;
+ virtual base::PlatformFileError SyncGetPlatformPath(
+ const fileapi::FileSystemURL& url,
+ base::FilePath* platform_path) OVERRIDE;
using base::SupportsWeakPtr<SyncableFileSystemOperation>::AsWeakPtr;
@@ -104,6 +117,8 @@ class SyncableFileSystemOperation
void OnCancelled();
const fileapi::FileSystemURL url_;
+ scoped_refptr<fileapi::FileSystemContext> file_system_context_;
+ scoped_ptr<fileapi::FileSystemOperationContext> operation_context_;
base::WeakPtr<SyncableFileOperationRunner> operation_runner_;
scoped_ptr<fileapi::FileSystemOperationImpl> inflight_operation_;
« no previous file with comments | « no previous file | chrome/browser/sync_file_system/local/syncable_file_system_operation.cc » ('j') | no next file with comments »
@@ -24,9 +26,9 @@ namespace sync_file_system {
class SyncableFileOperationRunner;
-// A wrapper class of FileSystemOperationImpl for syncable file system.
+// A wrapper class of FileSystemOperation for syncable file system.
class SyncableFileSystemOperation

Powered by Google App Engine
This is Rietveld 408576698